@@ -1,5 +1,7 @@
 import os
 
+from mobio.libs.caching import LruCache, StoreType
+
 
 class ConsumerGroup:
     DEFAULT_CONSUMER_GROUP_ID = "mobio-consumers"
@@ -18,6 +20,14 @@ class MobioEnvironment:
     REDIS_PORT = 'REDIS_PORT'
     KAFKA_BROKER = 'KAFKA_BROKER'
     KAFKA_REPLICATION_FACTOR = 'KAFKA_REPLICATION_FACTOR'
+    YEK_REWOP = 'YEK_REWOP'
 
 
 KAFKA_BOOTSTRAP = os.getenv(MobioEnvironment.KAFKA_BROKER)
+
+lru_cache_kafka = LruCache(
+    store_type=StoreType.REDIS,
+    # config_file_name=APP_CONFIG_FILE_PATH,
+    cache_prefix="kafka_lib_",
+    redis_uri=os.getenv(MobioEnvironment.REDIS_URI),
+)
